"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanupMessages = void 0;
const filter_ignored_process_1 = require("./filter-ignored-process");
const MessageProcessManager_1 = require("./MessageProcessManager");
const filter_duplicated_process_1 = require("./filter-duplicated-process");
const sort_messages_process_1 = require("./sort-messages-process");
const filter_message_id_1 = require("./filter-message-id");
const filter_mask_secrets_1 = require("./filter-mask-secrets");
/**
 * Post cleanup messages
 * - filter ignored range
 * - filter disabled message
 * - [masSecrets] mask secrets message
 * - filter duplicated messages
 * - sort messages by range
 * @param options
 */
const cleanupMessages = (options) => {
    const reportedMessages = filter_ignored_process_1.filterIgnoredMessages(options);
    const reportedMessagesWithoutAllowMessageIds = filter_message_id_1.filterByAllowMessageIds(reportedMessages, options.allowMessageIds);
    const filters = options.maskSecrets
        ? [filter_duplicated_process_1.filterDuplicatedMessages, filter_mask_secrets_1.filterMaskSecretsData]
        : [filter_duplicated_process_1.filterDuplicatedMessages];
    const filterProcess = MessageProcessManager_1.createMessageProcessor(filters);
    return sort_messages_process_1.sortMessagesByLocation(filterProcess.process(reportedMessagesWithoutAllowMessageIds));
};
exports.cleanupMessages = cleanupMessages;
//# sourceMappingURL=index.js.map